.. CHANGELOG.rst
.. Copyright (c) 2013-2017 Pablo Acosta-Serafini
.. See LICENSE for details

Changelog
=========

* 1.0.6 [2017-02-09]: Package build enhancements and fixes

* 1.0.5 [2017-02-07]: Python 3.6 support

* 1.0.4 [2016-06-11]: Minor documentation build bug fix

* 1.0.3 [2016-05-13]: Documentation update

* 1.0.2 [2016-05-11]: Documentation update

* 1.0.1 [2016-05-02]: Minor documentation and testing enhancements

* 1.0.0 [2016-04-25]: Final release of 1.0.0 branch

* 1.0.0rc1 [2016-04-25]: Initial commit, forked off putil PyPI package
